.. image:: https://img.shields.io/badge/licence-AGPL--1-blue.svg
    :target: http://www.gnu.org/licenses/agpl-3.0-standalone.html
    :alt: License: AGPL-3

User Log Details
================

This module developed to  record  login details of user.

Installation
============

Just select it from available modules to install it, there is no need to extra installations.

Configuration
=============

Nothing to configure.

Company
-------
* `Cybrosys Techno Solutions <https://cybrosys.com/>`__

Credits
-------
* Developer:
   Saritha @ cybrosys
   Muhammad P @ cybrosys

Contacts
--------
* Mail Contact : odoo@cybrosys.com
* Website : https://cybrosys.com

> :warning: This module has been uploaded to PyPI by Coopdevs Treball SCCL, but it was authored by Cybrosys. We need it on PyPI to streamline our deployments. For further details, you can contact sysadmin@coopdevs.org.

Bug Tracker
-----------
Bugs are tracked on GitHub Issues. In case of trouble, please check there if your issue has already been reported.

Maintainer
==========
.. image:: https://cybrosys.com/images/logo.png
   :target: https://cybrosys.com

This module is maintained by Cybrosys Technologies.

For support and more information, please visit `Our Website <https://cybrosys.com/>`__

Further information
===================
HTML Description: `<static/description/index.html>`__



